@@ -16,8 +16,8 @@ void
 Print(TYPE c)
 {
     const char c01[]=".1";  // characters for printing zero and one
-    print_bin("  c=", (ulong)c, TYPE_BITS, c01);
-    print_bin("  -c=", (ulong)-c, TYPE_BITS, c01);
+    print_bin("  c=", (unsigned long long)c, TYPE_BITS, c01);
+    print_bin("  -c=", (unsigned long long)-c, TYPE_BITS, c01);
     cout << "   c=" << setw(6) << (TYPE)+c;
     cout << "  -c=" << setw(6) << (TYPE)-c;
     // warning: conversion to ‘long long unsigned int’
