@@ -32,8 +32,8 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
-#ifdef ACYCLIC_MAP_MAX_ARRAY_LEN
+#if defined TIMING
+#if defined ACYCLIC_MAP_MAX_ARRAY_LEN
     cout << "ACYCLIC_MAP_MAX_ARRAY_LEN is defined" << endl;
 #endif
     M.first();
