@@ -34,10 +34,10 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     bool bw = 0;
     NXARG(bw, "Whether to generate in backward order");
-#ifdef ASCENT_RGS_FIXARRAYS
+#if defined ASCENT_RGS_FIXARRAYS
     cout << "ASCENT_RGS_FIXARRAYS defined." << endl;
 #endif
 
