@@ -33,7 +33,7 @@ main(int argc, char **argv)
     do
     {
         ++ct;
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(3) << ct << ":";
         const ulong *x = C.data();
         print_set("    ", x, k);
