@@ -76,21 +76,22 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
 
-% time ./bin 32 20
-arg 1: 32 == n  [Combinations (n choose k)]  default=7
+time ./bin 34 20
+arg 1: 34 == n  [Combinations (n choose k)]  default=7
 arg 2: 20 == k  [ k>=1]  default=3
- ct = 225792840
-./bin 32 20  1.08s user 0.00s system 99% cpu 1.076 total
- ==> binomial(32,20)/1.08 == 209,067,444 per second
+ ct = 1391975640
+1.91user 0.00system 0:01.91elapsed 100%CPU
+ ==> 1391975640/1.91 == 728,783,057 per second
 
-% time ./bin 32 12
-arg 1: 32 == n  [Combinations (n choose k)]  default=7
-arg 2: 12 == k  [ k>=1]  default=3
- ct = 225792840
-./bin 32 12  1.12s user 0.00s system 99% cpu 1.128 total
- ==> binomial(32,12)/1.12 == 201,600,750 per second
+time ./bin 34 14
+arg 1: 34 == n  [Combinations (n choose k)]  default=7
+arg 2: 14 == k  [ k>=1]  default=3
+ ct = 1391975640
+2.10user 0.00system 0:02.10elapsed 100%CPU
+ ==> 1391975640/2.10 == 662,845,542 per second
 
 */
 
