@@ -27,7 +27,7 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     do { ++ct; }  while  ( P.next() <= n );
 #else
 
