@@ -501,7 +501,7 @@ main(int argc, char **argv)
         st[ s ] += 1;
 
 
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
         C.print("  ");
         cout << setw(4) << s;
