@@ -10,6 +10,9 @@
 
 
 //% k-ary Dyck words via prefix shifts.
+//% Algorithm "coolkat" as given (left in figure "Algorithms 1") in
+//%   Stephane Durocher, Pak Ching Li, Debajyoti Mondal, Aaron Williams:
+//%   "Ranking and Loopless Generation of k-ary Dyck Words in Cool-lex Order",
 
 //#define TIMING  // uncomment to disable printing
 
@@ -57,6 +60,19 @@ main(int argc, char **argv)
 }
 // -------------------------
 
+/*
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
+
+time ./bin 18 2
+time ./bin 18 2
+arg 1: 18 == n  [Number of ones in words (n>=1).]  default=4
+arg 2: 2 == k  [k-ary Dyck words (k>=1, k==2 gives Catalan strings).]  default=3
+ ct=477638700
+0.51user 0.00system 0:00.51elapsed 100%CPU
+ ==> 477638700/0.51 == 936,546,470 per second
+*/
+
 /*
 Timing: (AMD Phenom II X4 945 3000MHz)
 
