@@ -523,7 +523,7 @@ main(int argc, char **argv)
         st[ s ] += 1;
 
 
-#ifndef TIMING  // whether to print anything
+#if !defined TIMING  // whether to print anything
         cout << setw(4) << ct << ":";
 
 //        P.print("  ");
