@@ -64,7 +64,6 @@ main(int argc, char **argv)
 
 //    ulong C[64];
     ulong num = S.first();
-//    ulong num = S.last();
 
     const ulong *x = S.data();
     do
@@ -83,7 +82,7 @@ main(int argc, char **argv)
 //        ulong nc = composition_nz_unrank(r, C, n+1);
 //        print_vec("  ", C, nc);
 
-//        cout << "  " << S.num_parts();
+        cout << "  " << S.num_parts();
         print_set("    ", x, num);
 //        cout << "  m = " << num;
         cout << endl;
@@ -91,7 +90,6 @@ main(int argc, char **argv)
         jjassert( S.OK() );
     }
     while ( (num = S.next()) );
-//    while ( (num = S.prev()) );
 
 #endif  // TIMING
 
