@@ -613,7 +613,7 @@ main(int argc, char **argv)
     {
         ++ct;
 
-#ifndef TIMING
+#if !defined TIMING
         cout << " " << setw(4) << ct << ":";
         M.print("  ", true );
         cout << "  " << M.pos();
