@@ -19,7 +19,7 @@
 
 const bool dfz = true;  // whether to print dots for zeros
 
-#ifndef TIMING
+#if !defined TIMING
 void visit(const mset_perm_lex_rec &P)
 {
     cout << setw(4) << P.ct_ << ":";
@@ -76,7 +76,7 @@ main(int argc, char **argv)
 
 
     cout << " ct=" << P.ct_ << endl;
-#ifndef TIMING
+#if !defined TIMING
     cout << " rct=" << P.rct_ << endl;
     cout << " rec/object=" << (double)(P.rct_)/(double)(P.ct_) << endl;
 #endif
