@@ -452,7 +452,7 @@ main(int argc, char **argv)
         st[ s ] += 1;
 
 
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
 
         // print RGS:
