@@ -111,26 +111,16 @@ Require: t >= s > 0
 
 
 /*
-Timing:
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
 
 // one-based array:
-
- time ./bin 18
+time ./bin 18
 arg 1: 18 == t  [Number of ones (t>0)]  default=5
 arg 2: 18 == s  [Number of zeros (s<=t)]  default=18
- ct = 477638700
-./bin 18  1.78s user 0.00s system 99% cpu 1.776 total
- ==> 477638700/1.78 == 268,336,348 per second
-
- time ./bin 18
-arg 1: 18 == t  [Number of ones (t>0)]  default=5
-arg 2: 18 == s  [Number of zeros (s<=t)]  default=18
-PAREN_PREF_FIXARRAYS is defined.
- ct = 477638700
-./bin 18  1.70s user 0.00s system 100% cpu 1.700 total
- ==> 477638700/1.70 == 280,963,941 per second
-
-// (zero-based array gives a slight slowdown)
+ ct=477638700
+0.45user 0.00system 0:00.45elapsed 100%CPU
+ ==> 477638700/0.45 == 1,061,419,333 per second
 
 */
 
