@@ -22,7 +22,7 @@ main(int argc, char **argv)
 
     perm_gray_ffact P(n);
 
-#ifdef TIMING
+#if defined TIMING
     while ( P.next() ) {;}
 #else
 
