@@ -23,11 +23,11 @@ main(int argc, char **argv)
 
     perm_lex P(n);
 
-#ifdef TIMING
-#ifdef PERM_LEX_FIXARRAYS
+#if defined TIMING
+#if defined PERM_LEX_FIXARRAYS
     cout << "PERM_LEX_FIXARRAYS is defined." << endl;
 #endif
-#ifdef PERM_LEX_OPT
+#if defined PERM_LEX_OPT
     cout << "PERM_LEX_OPT is defined." << endl;
 #endif
 
