@@ -35,7 +35,7 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     if ( bq )
     {
         cout << "backward:" << endl;
