@@ -38,7 +38,7 @@ main(int argc, char **argv)
     {
         random_connected_permutation(f, n);
 
-#ifndef TIMING
+#if !defined TIMING
         print_perm("   f=", f, n, false);
         print_cycles("    ", f, n);
         cout << endl;
