@@ -89,7 +89,7 @@ public:
     bool next()
     {
 #if defined PAREN_PREF_BASE1
-        if ( x_ >= nq_ )  return false;  // was last
+        if ( x_ >= nq_ )  return false;  // current is last
         b_[x_] = 0;
         b_[y_] = 1;
         ++x_;
@@ -107,7 +107,7 @@ public:
         }  // { else Case (a) }
         return true;
 #else
-        if ( x_+1 >= nq_ )  return false;  // was last
+        if ( x_+1 >= nq_ )  return false;  // current is last
         b_[x_] = 0;
         b_[y_] = 1;
         ++x_;
