@@ -17,8 +17,8 @@ class signed_perm
 // There are n! * 2^n signed permutations of n elements.
 {
 private:
-    perm_trotter P;  // permutation of coordinates
-    ruler_func R;  // for reflections
+    perm_trotter PR;  // permutation of coordinates
+    ruler_func RF;  // for reflections
     bool * refl_q;    // refl_q[j] says whether coordinate j is reflected
     bool perm_is_rot;    // whether permutation alone is a rotation
     bool refl_is_rot;    // whether reflections alone give a rotation
@@ -30,7 +30,7 @@ private:
 
 public:
     signed_perm(ulong tn)
-        : P(tn), R(tn), n(tn)
+        : PR(tn), RF(tn), n(tn)
     {
         refl_q = new bool[n];
         first();
@@ -44,7 +44,7 @@ private:
     void first_refl()
     // Set all reflections to false.
     {
-        R.first();
+        RF.first();
         // no coordinate reflected:
         refl_is_rot = true;
         for (ulong j=0; j<n; ++j)
@@ -52,9 +52,13 @@ private:
     }
 
 public:
+    const ulong * perm_data()  const  { return PR.data(); }
+    const ulong * perm_inv_data()  const  { return PR.invdata(); }
+    const bool * refl_data()  const  { return refl_q; }
+
     void first()
     {
-        P.first();
+        PR.first();
         perm_is_rot = true;
 
         first_refl();
@@ -63,7 +67,7 @@ public:
     bool next()
     {
         // next reflection:
-        const ulong r = R.next();
+        const ulong r = RF.next();
         refl_is_rot = ! refl_is_rot;  // one coordinate (namely r) is reversed
         if ( r < n )
         {
@@ -75,7 +79,7 @@ public:
 
         // next permutation:
         perm_is_rot = ! perm_is_rot;
-        return P.next();
+        return PR.next();
     }
 
     bool next_rotation()
@@ -95,15 +99,11 @@ public:
 
     bool next_perm()
     {
-        if ( ! P.next() )  return false;  // last perm
+        if ( ! PR.next() )  return false;  // last perm
         first_refl();
         return true;
     }
 
-    const ulong * perm_data()  const  { return P.data(); }
-
-    const bool * refl_data()  const  { return refl_q; }
-
     void print(const char * bla, bool offset_one_q=false)  const
     {
         using std::cout;
