@@ -1,7 +1,7 @@
 #if !defined HAVE_SHORTFHTDITCORE_H__
 #define      HAVE_SHORTFHTDITCORE_H__
 // This file is part of the FXT library.
-// Copyright (C) 2010, 2012, 2017 Joerg Arndt
+// Copyright (C) 2010, 2012, 2017, 2023 Joerg Arndt
 // License: GNU General Public License version 3 or later,
 // see the file COPYING.txt in the main directory.
 
@@ -697,5 +697,21 @@ inline void fht_dit_core_64(Type *f)
 // -------------------------
 // opcount by generator:  #mult=166=2.59375/pt   #add=462=7.21875/pt
 
+template <typename Type>
+inline void fht_dit_core_leq_64(Type *f, ulong n)
+// Must have n \in {2, 4, 8, 16, 32, 64}
+{
+    switch ( n )
+    {
+    case 2: fht_dit_core_2(f); break;
+    case 4: fht_dit_core_4(f); break;
+    case 8: fht_dit_core_8(f); break;
+    case 16: fht_dit_core_16(f); break;
+    case 32: fht_dit_core_32(f); break;
+    case 64: fht_dit_core_64(f); break;
+//    default: ;  // ouch...
+    }
+}
+// -------------------------
 
 #endif  // !defined HAVE_SHORTFHTDITCORE_H__
